@@ -177,10 +177,10 @@ impl<Source> PreprocessedFile<Source>
     }
 
     #[inline]
-    pub fn as_str(&self) -> &str { self.contents.as_ref() }
+    pub fn source(&self) -> &str { self.contents.as_ref() }
 
     #[inline]
-    pub fn len(&self) -> usize { self.as_str().len() }
+    pub fn len(&self) -> usize { self.source().len() }
 
 }
 
